@@ -24,7 +24,7 @@
 
 #include "support.h"
 #include "structure.h"
-#include "db.h"
+#include <gpe/contacts-db.h>
 #include "main.h"
 #include "namedetail.h"
 
@@ -52,7 +52,7 @@ void on_unknown_year_toggled (GtkToggleButton *togglebutton, gpointer user_data)
 void on_name_clicked (GtkButton *button, gpointer user_data);
 
 
-/* this is the filter for phone number edits */
+/* CALLBACK : this is the filter for phone number edits */
 void
 on_phone_insert_text(GtkEditable *editable, gchar *new_text,
                      gint new_text_length, gint *position,
@@ -226,13 +226,16 @@ build_children (GtkWidget *table, GSList *children, GtkWidget *pw, gboolean visi
           else
             gtk_widget_hide(ww);
           gtk_text_view_set_editable (GTK_TEXT_VIEW (ww), TRUE);
-          gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (ww), GTK_WRAP_WORD);
+          gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (ww), GTK_WRAP_WORD_CHAR);
           g_signal_connect(G_OBJECT(ww),"move_cursor",
             G_CALLBACK(tv_move_cursor),NULL);
           g_signal_connect(G_OBJECT(ww),"focus-in-event",
             G_CALLBACK(tv_focus_in),NULL);
           g_signal_connect(G_OBJECT(ww),"focus-out-event",
             G_CALLBACK(tv_focus_out),NULL);
+          /*HACK: This is a workaround for a bug in the GtkTextView implementation 
+            causing it to grow while entering text. */
+          gtk_widget_set_size_request(ww, 5, -1);
           
 #ifndef IS_HILDON
           gtk_widget_set_usize (GTK_WIDGET (ww), -1, 36);
@@ -249,7 +252,8 @@ build_children (GtkWidget *table, GSList *children, GtkWidget *pw, gboolean visi
           (*pos)++;
           if (e->name) gtk_table_attach(GTK_TABLE(table), w, 0, 1, *pos, *pos+1, 
                                         GTK_FILL, GTK_FILL, 0, 0);
-          gtk_table_attach_defaults(GTK_TABLE(table), ww, 1, 3, *pos, *pos+1);
+          gtk_table_attach(GTK_TABLE(table), ww, 1, 3, *pos, *pos+1, 
+                           GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND, 0, 0);
           add_tag (e->tag, ww, pw);
         break;
       
@@ -518,6 +522,7 @@ create_edit (void)
 GtkWidget *
 edit_window (gboolean isdialog)
 {
+  /* Create the window */
   GtkWidget *w = create_edit ();
   GtkWidget *book = lookup_widget (w, "notebook2");
   GSList *page;
@@ -578,7 +583,7 @@ edit_window (gboolean isdialog)
 }
 
 static GSList *
-get_categories_list (struct person *p)
+get_categories_list (struct contacts_person *p)
 {
   GSList *iter;
   GSList *list = NULL;
@@ -587,7 +592,7 @@ get_categories_list (struct person *p)
 
   for (; iter; iter = iter->next)
     {
-      struct tag_value *t = iter->data;
+      struct contacts_tag_value *t = iter->data;
       if (!strcasecmp (t->tag, "category"))
         {
           int id = atoi (t->value);
@@ -599,7 +604,7 @@ get_categories_list (struct person *p)
 }
 
 gchar *
-build_categories_string (struct person *p)
+build_categories_string (struct contacts_person *p)
 {
   gchar *s = NULL;
   GSList *iter, *list;
@@ -632,7 +637,7 @@ build_categories_string (struct person *p)
 static void
 update_categories_list (GtkWidget *ui, GSList *selected, GtkWidget *edit)
 {
-  struct person *p;
+  struct contacts_person *p;
 #ifndef IS_HILDON
   GtkWidget *w;
   gchar *str;
@@ -640,11 +645,11 @@ update_categories_list (GtkWidget *ui, GSList *selected, GtkWidget *edit)
   GSList *iter;
 
   p = g_object_get_data (G_OBJECT (edit), "person");
-  db_delete_tag (p, "category");
+  contacts_db_delete_tag (p, "category");
 
   for (iter = selected; iter; iter = iter->next)
     {
-      db_set_multi_data (p, "category", g_strdup_printf ("%d", (int)iter->data));
+      contacts_db_set_multi_data (p, "category", g_strdup_printf ("%d", (int)iter->data));
     }
 
 #ifndef IS_HILDON
@@ -656,9 +661,11 @@ update_categories_list (GtkWidget *ui, GSList *selected, GtkWidget *edit)
 }
 
 void
-edit_person (struct person *p, gchar *title, gboolean isdialog)
+edit_person (struct contacts_person *p, gchar *title, gboolean isdialog)
 {
-  GtkWidget *w = edit_window (isdialog);
+  /* Create the window */
+  GtkWidget *window = edit_window (isdialog);
+
 #ifdef IS_HILDON    
   GSList *catlist = NULL;
 #else    
@@ -666,35 +673,40 @@ edit_person (struct person *p, gchar *title, gboolean isdialog)
   GtkWidget *catlabel;
 #endif
     
-  gtk_window_set_title (GTK_WINDOW (w), title);
-  g_object_set_data(G_OBJECT(w), "isdialog", (gpointer)isdialog);  
+  gtk_window_set_title (GTK_WINDOW (window), title);
+  g_object_set_data(G_OBJECT(window), "isdialog", (gpointer)isdialog);  
   
   if (p)
     {
-      GSList *tags = gtk_object_get_data (GTK_OBJECT (w), "tag-widgets");
+      GSList *tags = gtk_object_get_data (GTK_OBJECT (window), "tag-widgets");
+
+      /* For all widgets corresponding to editable tags */
       GSList *iter;
       for (iter = tags; iter; iter = iter->next)
         {
-          GtkWidget *w = iter->data;
-          gchar *tag = gtk_object_get_data (GTK_OBJECT (w), "db-tag");
-          struct tag_value *v = db_find_tag (p, tag);
+          GtkWidget *widget = iter->data;
+
+	  /* Get the data associated to the corresponding tag in the database */
+          gchar *tag = gtk_object_get_data (GTK_OBJECT (widget), "db-tag");
+          struct contacts_tag_value *v = contacts_db_find_tag (p, tag);
+
           guint pos = 0;
           if (tag)
             {
                if (!strcasecmp(tag, "NAME"))
                  {
-                   gtk_widget_grab_default(w);
-                   gtk_widget_grab_focus(w);
+                   gtk_widget_grab_default(widget);
+                   gtk_widget_grab_focus(widget);
                  }
             }
           if (v && v->value)
             {
-              if (GTK_IS_EDITABLE (w))
+              if (GTK_IS_EDITABLE (widget))
                 {
-                  gtk_editable_insert_text (GTK_EDITABLE (w), v->value,
+                  gtk_editable_insert_text (GTK_EDITABLE (widget), v->value,
                           strlen (v->value), &pos);
                 }
-              else if (GTK_IS_DATE_COMBO(w))
+              else if (GTK_IS_DATE_COMBO(widget))
                 {
                   if (v->value)
                     {
@@ -702,101 +714,170 @@ edit_person (struct person *p, gchar *title, gboolean isdialog)
                       GtkToggleButton *cbnoyear;
                       
                       sscanf (v->value, "%04d%02d%02d", &year, &month, &day);
-                      gtk_date_combo_set_date (GTK_DATE_COMBO (w), year, month, day);
+                      gtk_date_combo_set_date (GTK_DATE_COMBO (widget), year, month, day);
                       if (year == 0)
                         {
-                          gtk_date_combo_ignore_year(GTK_DATE_COMBO(w),TRUE);
-                          cbnoyear = g_object_get_data(G_OBJECT(w),"cbnoyear");
+                          gtk_date_combo_ignore_year(GTK_DATE_COMBO(widget),TRUE);
+                          cbnoyear = g_object_get_data(G_OBJECT(widget),"cbnoyear");
                           gtk_toggle_button_set_active(cbnoyear,TRUE);
                         }
                     }
                   else
-                    gtk_date_combo_clear (GTK_DATE_COMBO (w));
+                    gtk_date_combo_clear (GTK_DATE_COMBO (widget));
                 }
-              else if (GTK_IS_IMAGE(w))
+              else if (GTK_IS_IMAGE(widget))
                 {
                   if ((v->value) && !access(v->value,R_OK)) 
                     {
                       GdkPixbuf *buf;
-                      g_object_set_data(G_OBJECT(w), "filename", v->value);
+                      g_object_set_data(G_OBJECT(widget), "filename", v->value);
                       buf = gdk_pixbuf_new_from_file_at_size(v->value, IMG_WIDTH, 
                                                              IMG_HEIGHT, NULL);
-                      gtk_image_set_from_pixbuf(GTK_IMAGE(w), buf);
+                      gtk_image_set_from_pixbuf(GTK_IMAGE(widget), buf);
                       gdk_pixbuf_unref(buf);
                     }
                   else
-                    gtk_image_set_from_stock(GTK_IMAGE(w), 
+                    gtk_image_set_from_stock(GTK_IMAGE(widget), 
                       GTK_STOCK_MISSING_IMAGE, GTK_ICON_SIZE_BUTTON);
                 }
               else  
-                gtk_text_buffer_set_text (gtk_text_view_get_buffer (GTK_TEXT_VIEW (w)), 
+                gtk_text_buffer_set_text (gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget)), 
                           v->value, -1);
             }
         }
-      gtk_object_set_data (GTK_OBJECT (w), "person", p);
+      gtk_object_set_data (GTK_OBJECT (window), "person", p);
 
 #ifdef IS_HILDON
       catlist = get_categories_list (p);
 #else
       /* display categories */  
       str = build_categories_string (p);
-      catlabel = lookup_widget (w, "categories-label");
+      catlabel = lookup_widget (window, "categories-label");
       gtk_label_set_text (GTK_LABEL (catlabel), str);
       g_free (str);
 #endif        
     }
 #ifdef IS_HILDON
-  populate_pim_categories_list(g_object_get_data(G_OBJECT(w), "categories"), 
+  populate_pim_categories_list(g_object_get_data(G_OBJECT(window), "categories"), 
                                catlist);
   if (catlist)
       g_slist_free(catlist);
 #endif  
-  gtk_widget_show (w);
+  gtk_widget_show (window);
+}
+
+/* Concatenate name parts. 
+   caller is responsible for freeing returned value */
+
+gchar *concatenate_name_parts(gchar *n1, gchar *n2, gchar *n3, gchar *n4,gchar *n5)
+{
+  gchar *ts = g_strdup("");
+  if (n1 && strlen(n1))
+    {
+      n1 = g_strdup_printf("%s%s ", ts, g_strstrip(n1));
+      g_free(ts);
+      ts = n1;
+    }
+  if (n2 && strlen(n2))
+    {
+      n1 = g_strdup_printf("%s%s ", ts, g_strstrip(n2));
+      g_free(ts);
+      ts = n1;
+    }
+  if (n3 && strlen(n3)) 
+    {
+      n1 = g_strdup_printf("%s%s ", ts, g_strstrip(n3));
+      g_free(ts);
+      ts = n1;
+    }
+  if (n4 && strlen(n4)) 
+    {
+      n1 = g_strdup_printf("%s%s ", ts, g_strstrip(n4));
+      g_free(ts);
+      ts = n1;
+    }
+  if (n5 && strlen(n5)) 
+    {
+      n1 = g_strdup_printf("%s%s", ts, g_strstrip(n5));
+      g_free(ts);
+      ts = n1;
+    }
+  g_strstrip(ts);
+  return ts;
 }
 
 void
-update_edit (struct person *p, GtkWidget *w)
+update_edit (struct contacts_person *p, GtkWidget *window)
 {
-  GtkWidget *nameentry[5];
+  GtkWidget *nameentry[6];
   int namenum = 0;
   int i;
-  gchar *n1 = NULL, *n2 = NULL, *n3 = NULL, *n4 = NULL, *n5 = NULL;
+  gchar *namepart[6];
+
+  for(i = 0; i < 6; i++)
+    {
+      nameentry[i] = NULL;
+      namepart[i] = NULL;
+    }
+
   if (p)
     {
-      GSList *tags = gtk_object_get_data (GTK_OBJECT (w), "tag-widgets");
+      GSList *tags = gtk_object_get_data (GTK_OBJECT (window), "tag-widgets");
+
+      /* For every widgets corresponding to tags in the window */
       GSList *iter;
       for (iter = tags; iter; iter = iter->next)
         {
-          GtkWidget *w = iter->data;
-          gchar *tag = gtk_object_get_data (GTK_OBJECT (w), "db-tag");
-          struct tag_value *v = db_find_tag (p, tag);
+          GtkWidget *widget = iter->data;
+          gchar *tag = gtk_object_get_data (GTK_OBJECT (widget), "db-tag");
+          struct contacts_tag_value *v = contacts_db_find_tag (p, tag);
           guint pos = 0;
           if (v && v->value)
             {
-               /* collect data for name field update */
-              if (!strcasecmp(v->tag,"TITLE"))
-                n1 = v->value;
-              if (!strcasecmp(v->tag,"GIVEN_NAME"))
-                n2 = v->value;
-              if (!strcasecmp(v->tag,"MIDDLE_NAME"))
-                n3 = v->value;
-              if (!strcasecmp(v->tag,"FAMILY_NAME"))
-                n4 = v->value;
-              if (!strcasecmp(v->tag,"HONORIFIC_SUFFIX"))
-                n5 = v->value;
-              if (!strcasecmp(v->tag,"NAME"))
-              {
-                nameentry[namenum] = w;
-                namenum++;
-              }
+	      /* collect data for name field update */
+	      if (!strcasecmp(tag,"NAME"))
+		{
+		  nameentry[5] = widget;
+		  namepart[5] = v->value;
+		}
+              if (!strcasecmp(tag,"TITLE"))
+		{
+		  nameentry[0] = widget;
+		  namepart[0] = v->value;
+		  namenum++;
+		}
+              if (!strcasecmp(tag,"GIVEN_NAME"))
+		{
+		  nameentry[1] = widget;
+		  namepart[1] = v->value;
+		  namenum++;
+		}
+              if (!strcasecmp(tag,"MIDDLE_NAME"))
+		{
+		  nameentry[2] = widget;
+		  namepart[2] = v->value;
+		  namenum++;
+		}
+              if (!strcasecmp(tag,"FAMILY_NAME"))
+		{
+		  nameentry[3] = widget;
+		  namepart[3] = v->value;
+		  namenum++;
+		}
+              if (!strcasecmp(tag,"HONORIFIC_SUFFIX"))
+		{
+		  nameentry[4] = widget;
+		  namepart[4] = v->value;
+		  namenum++;
+		}
 
-              if (GTK_IS_EDITABLE (w))
+              if (GTK_IS_EDITABLE (widget))
                 {
-                  gtk_editable_delete_text(GTK_EDITABLE(w), 0, -1);
-                  gtk_editable_insert_text (GTK_EDITABLE (w), v->value,
+                  gtk_editable_delete_text(GTK_EDITABLE(widget), 0, -1);
+                  gtk_editable_insert_text (GTK_EDITABLE (widget), v->value,
                                             strlen (v->value), &pos);
                 }
-              else if (GTK_IS_DATE_COMBO(w))
+              else if (GTK_IS_DATE_COMBO(widget))
                 {
                   if (v->value)
                     {
@@ -804,101 +885,94 @@ update_edit (struct person *p, GtkWidget *w)
                       GtkToggleButton *cbnoyear;
                       
                       sscanf (v->value, "%04d%02d%02d", &year, &month, &day);
-                      gtk_date_combo_set_date (GTK_DATE_COMBO (w), year, month, day);
+                      gtk_date_combo_set_date (GTK_DATE_COMBO (widget), year, month, day);
                       if (year == 0)
                         {
-                          gtk_date_combo_ignore_year(GTK_DATE_COMBO(w),TRUE);
-                          cbnoyear = g_object_get_data(G_OBJECT(w),"cbnoyear");
+                          gtk_date_combo_ignore_year(GTK_DATE_COMBO(widget),TRUE);
+                          cbnoyear = g_object_get_data(G_OBJECT(widget),"cbnoyear");
                           gtk_toggle_button_set_active(cbnoyear,TRUE);
                         }
                     }
                   else
-                    gtk_date_combo_clear (GTK_DATE_COMBO (w));
+                    gtk_date_combo_clear (GTK_DATE_COMBO (widget));
                 }
-              else if (GTK_IS_IMAGE(w))
+              else if (GTK_IS_IMAGE(widget))
                 {
-                  g_object_set_data(G_OBJECT(w),"filename",v->value);
+                  g_object_set_data(G_OBJECT(widget),"filename",v->value);
                   if ((v->value) && !access(v->value,R_OK))
                     {
                       GdkPixbuf *buf;
-                      g_object_set_data(G_OBJECT(w), "filename", v->value);
+                      g_object_set_data(G_OBJECT(widget), "filename", v->value);
                       buf = gdk_pixbuf_new_from_file_at_size(v->value, IMG_WIDTH, 
                                                              IMG_HEIGHT, NULL);
-                      gtk_image_set_from_pixbuf(GTK_IMAGE(w), buf);
+                      gtk_image_set_from_pixbuf(GTK_IMAGE(widget), buf);
                       gdk_pixbuf_unref(buf);
                     }
                   else
-                    gtk_image_set_from_stock(GTK_IMAGE(w), 
+                    gtk_image_set_from_stock(GTK_IMAGE(widget), 
                       GTK_STOCK_MISSING_IMAGE, GTK_ICON_SIZE_BUTTON);
                 }
-              else if (GTK_IS_TEXT_VIEW(w))
-                gtk_text_buffer_set_text (gtk_text_view_get_buffer (GTK_TEXT_VIEW (w)), 
+              else if (GTK_IS_TEXT_VIEW(widget))
+                gtk_text_buffer_set_text (gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget)), 
                           v->value, -1);
             }
+
         }
     }
 
   if (namenum)
     {
-      gchar *ts = g_strdup(n1);
-      if (n2)
-        {
-          n1 = g_strdup_printf("%s %s", ts, g_strstrip(n2));
-          g_free(ts);
-          ts = n1;
-        }
-      if (n3) 
-        {
-          n1 = g_strdup_printf("%s %s", ts, g_strstrip(n3));
-          g_free(ts);
-          ts = n1;
-        }
-      if (n4) 
-        {
-          n1 = g_strdup_printf("%s %s", ts, g_strstrip(n4));
-          g_free(ts);
-          ts = n1;
-        }
-      if (n5) 
-        {
-          n1 = g_strdup_printf("%s %s", ts, g_strstrip(n5));
-          g_free(ts);
-          ts = n1;
-        }
+      gchar *ts = concatenate_name_parts(namepart[0], namepart[1], namepart[2], namepart[3], namepart[4]);
 
-      for (i=0;i<namenum;i++)
-        gtk_entry_set_text(GTK_ENTRY(nameentry[i]), g_strstrip(ts));
+      /* First update value of concatenated name */
+      contacts_db_set_data(p, "NAME", g_strdup(ts));
+      if (nameentry[5])
+	gtk_entry_set_text(GTK_ENTRY(nameentry[5]), ts);
       g_free(ts);
+
+      /* Then the sub-components */
+      for (i = 0; i < 5; i++)
+	{
+	  if (nameentry[i])
+	    {
+	      gtk_entry_set_text(GTK_ENTRY(nameentry[i]), namepart[i]);
+	    }
+	}
+
     }
 }
 
 
 void
-store_name_fields(struct person *p, const char *nametext)
+store_name_fields(struct contacts_person *p, const char *nametext)
 {
-char e[4][100];
-int num_elements, i;
-gboolean has_title = FALSE, has_suffix = FALSE;
-char *sp;
-char *title = NULL;
-char *first = NULL;
-char *middle = NULL;
-char *last = NULL;
-char *suffix = NULL;
+  char e[4][100];
+  int num_elements, i;
+  gboolean has_title = FALSE, has_suffix = FALSE;
+  char *sp;
+  /*  char *origsp; */
+  char *title = NULL;
+  char *first = NULL;
+  char *middle = NULL;
+  char *last = NULL;
+  char *suffix = NULL;
+  char *refsuffix = NULL;
    
   if (!nametext) return;
   if (strlen(nametext) < 3) return;
-    sp = g_strdup(nametext);
 
-    /* scan first element for title */
-    if (sscanf(sp, "%s", e[0]))
+  sp = g_strdup(nametext);
+  /*  origsp = sp; */
+
+  /* scan first element for title */
+  if (sscanf(sp, "%s", e[0]))
       {
-        struct tag_value *v;
+        struct contacts_tag_value *v;
         i = 0;
         
         while (titles[i])
           {
-            if (!strcasecmp(e[0], titles[i]))
+            if (!strcasecmp(e[0], gettext(titles[i])))
               {
                 has_title = TRUE;
                 title = sp;
@@ -910,7 +984,7 @@ char *suffix = NULL;
           }
         if (!has_title) /* find user defined title */
           {
-            v = db_find_tag(p, "TITLE");
+            v = contacts_db_find_tag(p, "TITLE");
             if (v && v->value && !strcasecmp(e[0], v->value))
               {
                 has_title = TRUE;
@@ -931,11 +1005,12 @@ char *suffix = NULL;
         i = 0;
         while (suffixes[i])
           {
-            if (!strcmp(suffix, suffixes[i]))
+	    refsuffix = gettext(suffixes[i]);
+            if (!strcmp(suffix, refsuffix))
               {
                 char *t;
                 has_suffix = TRUE;
-                t = strstr(sp, suffixes[i]);
+                t = strstr(sp, refsuffix);
                 if (t)
                   {
                     t--;
@@ -958,10 +1033,10 @@ char *suffix = NULL;
       {
         case 0: 
         case EOF:
-        break;
+	  break;
         case 1: 
           last = e[0];
-        break;
+	  break;
         case 2: 
           if (strstr(sp, ","))
             {
@@ -979,7 +1054,7 @@ char *suffix = NULL;
                 last++;
               strrchr(sp, ' ')[0] = 0;
             }
-        break;
+	  break;
         default:
           if (strstr(sp, ","))
             {
@@ -1009,24 +1084,30 @@ char *suffix = NULL;
                   strrchr(first, ' ')[0] = 0;
                 }
             }
-        break;
+	  break;
       }
-    db_set_data(p, "GIVEN_NAME", g_strdup(first));
-    db_set_data(p, "MIDDLE_NAME", g_strdup(middle));
-    db_set_data(p, "FAMILY_NAME", g_strdup(last));
-    db_set_data(p, "TITLE", g_strdup(title));
-    db_set_data(p, "HONORIFIC_SUFFIX", g_strdup(suffix));
+    contacts_db_set_data(p, "GIVEN_NAME", g_strdup(first));
+    contacts_db_set_data(p, "MIDDLE_NAME", g_strdup(middle));
+    contacts_db_set_data(p, "FAMILY_NAME", g_strdup(last));
+    contacts_db_set_data(p, "TITLE", g_strdup(title));
+    contacts_db_set_data(p, "HONORIFIC_SUFFIX", g_strdup(suffix));
+
+    /*    g_free(origsp); */
+
 }
 
 
+/* CALLBACK */
+
 void
 on_edit_save_clicked (GtkButton * button, gpointer user_data)
 {
   GtkWidget *edit = (GtkWidget *) user_data;
   GSList *tags;
-  struct person *p = g_object_get_data (G_OBJECT (edit), "person");
+  struct contacts_person *p = g_object_get_data (G_OBJECT (edit), "person");
   gchar *nametext = NULL;
   gboolean isdialog = (gboolean) g_object_get_data(G_OBJECT(edit), "isdialog");
+  gchar *n1 = NULL, *n2 = NULL, *n3 = NULL, *n4 = NULL, *n5 = NULL;
   
   for (tags = g_object_get_data (G_OBJECT (edit), "tag-widgets");
        tags; tags = tags->next)
@@ -1066,18 +1147,51 @@ on_edit_save_clicked (GtkButton * button, gpointer user_data)
           text = gtk_text_buffer_get_text (buf, &start, &end, FALSE);
         }
       tag = g_object_get_data (G_OBJECT (w), "db-tag");
-      db_set_data (p, tag, text);
+      contacts_db_set_data (p, tag, text);
       
-      /* remember name */
+      /* remember name details components for later comparison */
+      if (!strcasecmp(tag,"TITLE"))
+	{
+	  n1 = text;
+	}
+      if (!strcasecmp(tag,"GIVEN_NAME"))
+	{
+	  n2 = text;
+	}
+      if (!strcasecmp(tag,"MIDDLE_NAME"))
+	{
+	  n3 = text;
+	}
+      if (!strcasecmp(tag,"FAMILY_NAME"))
+	{
+	  n4 = text;
+	}
+      if (!strcasecmp(tag,"HONORIFIC_SUFFIX"))
+	{
+	  n5 = text;
+	}
+
       if (!strcasecmp(tag, "NAME"))
         {
-            nametext = text;
+	  nametext = text;
         }
     }
 
-    /* handle name details */
+    /* handle name modification */
     if (nametext)
-      store_name_fields(p, nametext);
+      {
+	/* concatenate name details parts to compare previous values
+	   to potential recent change of "full" name */
+	gchar *oldnametext = concatenate_name_parts(n1, n2, n3, n4, n5);
+	
+	/* only if "full" name was changed since previous edition of
+	   name details, we need to parse again the name details and
+	   update name details values accordingly */
+	if(strcmp(nametext, oldnametext))
+	  store_name_fields(p, nametext);
+
+	g_free(oldnametext);
+      }
 
 #ifdef IS_HILDON
     {   
@@ -1088,7 +1202,7 @@ on_edit_save_clicked (GtkButton * button, gpointer user_data)
         g_slist_free(categories);
     } 
 #endif
-  if (commit_person (p))
+  if (contacts_commit_person (p))
     {
       gtk_widget_destroy (edit);
       if (isdialog)
@@ -1097,7 +1211,7 @@ on_edit_save_clicked (GtkButton * button, gpointer user_data)
         }
       else
         {
-          discard_person (p);
+          contacts_discard_person (p);
           update_display ();
         }
     }
@@ -1106,7 +1220,7 @@ on_edit_save_clicked (GtkButton * button, gpointer user_data)
 void
 on_categories_clicked (GtkButton *button, gpointer user_data)
 {
-  struct person *p;
+  struct contacts_person *p;
   GtkWidget *w;
 
   p = g_object_get_data (G_OBJECT (user_data), "person");
@@ -1279,19 +1393,41 @@ on_unknown_year_toggled (GtkToggleButton *togglebutton, gpointer user_data)
   gtk_date_combo_ignore_year(cb, gtk_toggle_button_get_active(togglebutton));
 }
 
+/* CALLBACK */
+
 void
 on_name_clicked (GtkButton *button, gpointer user_data)
 {
   GtkWindow *edit = user_data;
   GtkEntry *e = g_object_get_data(G_OBJECT(button), "edit");
-  struct person *p;
-  gchar *name;
-
+  struct contacts_person *p;
+  gchar *oldname = "";
+  gchar *name = NULL;
+  struct contacts_tag_value *v;
+ 
   p = g_object_get_data (G_OBJECT (edit), "person");
   
+  /* get the name displayed in the widget */
   name = gtk_editable_get_chars(GTK_EDITABLE(e), 0, -1);
-  store_name_fields(p, name);
+
+  /* get the name in the person's tags */
+  v = contacts_db_find_tag(p,"NAME");
+  if (v && v->value) 
+    oldname = v->value;
+
+  /* if both names differ, name was edited */
+  if(strcmp(oldname,name))
+    {
+    
+      /* so split the name into parts before editing details */
+      store_name_fields(p, name);
+    }
   g_free(name);
+
+  /* Display the name details dialog */
   if (do_edit_name_detail(edit, p))
-    update_edit(p, GTK_WIDGET(edit));
+    {
+      /* Then update contents of name widget */
+      update_edit(p, GTK_WIDGET(edit));
+    }
 }
